Introduction
---------------

ContactBWC is a component for `BlazeWeb <http://pypi.python.org/pypi/BlazeWeb/>`_
applications.  It provides a contact form and an administrative interface
for updating available contacts.

Questions & Comments
---------------------

Please visit: http://groups.google.com/group/blazelibs

Current Status
---------------

The code stays pretty stable, but the API may change in the future.

The `ContactBWC tip <http://bitbucket.org/rsyring/contactbwc/get/tip.zip#egg=ContactBWC-dev>`_
is installable via `easy_install` with ``easy_install ContactBWC==dev``.
